@@ -24,9 +24,11 @@ pub(super) struct RegisterCluster {
     default_state: Option<String>,
     claim_unowned_states: bool,
     cleanup_grace: String,
+    azure: AzureCredentials,
 }
 
 impl RegisterCluster {
+    #[allow(clippy::too_many_arguments)]
     pub(super) fn new(
         helm: k8s::Helm,
         provider: Option<v0::Provider>,
@@ -35,6 +37,7 @@ impl RegisterCluster {
         default_state: Option<String>,
         claim_unowned_states: bool,
         cleanup_grace: String,
+        azure: AzureCredentials,
     ) -> Self {
         Self {
             helm,
@@ -44,6 +47,7 @@ impl RegisterCluster {
             default_state,
             claim_unowned_states,
             cleanup_grace,
+            azure,
         }
     }
 
@@ -86,6 +90,13 @@ impl StateHub {
 
         self.setup_cluster_token_helper(&cluster, &register_cluster)
             .await?;
+        self.setup_credentials_helper(
+            &kubectl,
+            &register_cluster.namespace,
+            Some(&register_cluster.azure),
+            None,
+        )
+        .await?;
         self.setup_configmap_helper(&kubectl, &cluster, &register_cluster)
             .await?;
 
@@ -324,6 +335,30 @@ or run following commands before running 'statehub register-cluster`
         Ok(())
     }
 
+    pub(super) async fn setup_credentials_helper(
+        &self,
+        kubectl: &k8s::Kubectl,
+        namespace: &str,
+        azure: Option<&AzureCredentials>,
+        aws: Option<()>,
+    ) -> anyhow::Result<()> {
+        let azure = if let Some(azure) = azure {
+            json::to_value(azure)?
+        } else {
+            json::json!({})
+        };
+        let _secret = kubectl.store_azure_credentials(namespace, azure).await?;
+
+        let aws = if let Some(aws) = aws {
+            json::to_value(aws)?
+        } else {
+            json::json!({})
+        };
+        let _secret = kubectl.store_aws_credentials(namespace, aws).await?;
+
+        Ok(())
+    }
+
     pub(super) async fn claim_unowned_states_helper(
         &self,
         cluster: &v0::Cluster,
